==> haskell-reinterpret-cast-0.1.0-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reinterpret-cast
version:              0.1.0
visibility:           public
id:                   reinterpret-cast-0.1.0-HA8KwzwJhGvFEpo4n2wnr7
key:                  reinterpret-cast-0.1.0-HA8KwzwJhGvFEpo4n2wnr7
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/reinterpret-cast
synopsis:
    Memory reinterpretation casts for Float/Double and Word32/Word64

description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.

    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.

category:             Data
abi:                  6aa301b58ec11045b03b09aa116238b2
exposed:              True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI

import-dirs:          /usr/lib/ghc-8.10.3/site-local/reinterpret-cast-0.1.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/reinterpret-cast-0.1.0
hs-libraries:         HSreinterpret-cast-0.1.0-HA8KwzwJhGvFEpo4n2wnr7
depends:              array-0.5.4.0 base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock

haddock-html:         /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reinterpret-cast-0.1.0-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reinterpret-cast
version:              0.1.0
visibility:           public
id:                   reinterpret-cast-0.1.0-KNg6esUmtRjG8cOvD7L0im
key:                  reinterpret-cast-0.1.0-KNg6esUmtRjG8cOvD7L0im
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/reinterpret-cast
synopsis:
    Memory reinterpretation casts for Float/Double and Word32/Word64

description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.

    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.

category:             Data
abi:                  cb464f8bdd8972f6734e31d91aeadad1
exposed:              True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI

import-dirs:          /usr/lib/ghc-8.10.3/site-local/reinterpret-cast-0.1.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/reinterpret-cast-0.1.0
hs-libraries:         HSreinterpret-cast-0.1.0-KNg6esUmtRjG8cOvD7L0im
depends:              array-0.5.4.0 base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock

haddock-html:         /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
